==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/resolver/impl/$SubmitTagUserExportJobMutationResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
final public class $SubmitTagUserExportJobMutationResolver implements SubmitTagUserExportJobMutationResolver {

    private GrowingIOConfig growingIOConfig;

    public $SubmitTagUserExportJobMutationResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $SubmitTagUserExportJobMutationResolver() {}

    @javax.validation.constraints.NotNull
    @Override
    public TagUserExportJobDto submitTagUserExportJob(String tagId, java.util.List<String> properties, String charset, Boolean detailExport) throws Exception {
        SubmitTagUserExportJobMutationRequest request = new SubmitTagUserExportJobMutationRequest();
        List<String> keys = Arrays.asList("tagId", "properties", "charset", "detailExport");
        List<?> values = Arrays.asList(tagId, properties, charset, detailExport);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        TagUserExportJobResponseProjection projection = new TagUserExportJobResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        SubmitTagUserExportJobMutationResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, SubmitTagUserExportJobMutationResponse.class);
        return result.submitTagUserExportJob();
    }

}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/resolver/impl/$SubmitTagUserExportJobMutationResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

/**
 * 提交用户标签导出任务  exportFileName: 导出的文件名称，不带后缀
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
final public class $SubmitTagUserExportJobMutationResolver implements SubmitTagUserExportJobMutationResolver {

    private GrowingIOConfig growingIOConfig;

    public $SubmitTagUserExportJobMutationResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $SubmitTagUserExportJobMutationResolver() {}

    /**
     * 提交用户标签导出任务  exportFileName: 导出的文件名称，不带后缀
     */
    @javax.validation.constraints.NotNull
    @Override
    public TagUserExportJobDto submitTagUserExportJob(String tagId, String exportFileName, java.util.List<String> properties, String charset, Boolean detailExport) throws Exception {
        SubmitTagUserExportJobMutationRequest request = new SubmitTagUserExportJobMutationRequest();
        List<String> keys = Arrays.asList("tagId", "exportFileName", "properties", "charset", "detailExport");
        List<?> values = Arrays.asList(tagId, exportFileName, properties, charset, detailExport);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        TagUserExportJobResponseProjection projection = new TagUserExportJobResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        SubmitTagUserExportJobMutationResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, SubmitTagUserExportJobMutationResponse.class);
        return result.submitTagUserExportJob();
    }

}
